@@ -2,6 +2,7 @@
 Contains common trace extractors and delegators
 """
 from flask import request, g
+from flask_trace_util.gunicorn_logger import GunicornLogger
 
 
 def gcloud_trace_extractor(project_id):
@@ -35,3 +36,19 @@ def gcloud_trace_delegator():
             return "X-Cloud-Trace-Context", ""
 
     return delegator
+
+
+class GCloudGunicornAccesLogger(GunicornLogger):
+    """ Acces logger for flask, gunicorn and google cloud
+
+    Arguments:
+        GunicornLogger {type} -- flask trace util GunicornLogger
+    """
+
+    def get_custom_variables(self, *args):
+        """Returns custom variables for acces logging
+
+        Returns:
+            dict -- custom env variables
+        """
+        return {"logging.googleapis.com/trace": g.trace}
